@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.10.2.2 2005/01/20 15:41:35 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.15 2004/12/17 19:10:19 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -116,13 +116,13 @@ load_one_gesture (EphyGesturesExtension *extension,
 
 	for (child = node->children; child != NULL; child = child->next)
 	{
-		if (xmlStrEqual (child->name, (const xmlChar*) "sequence"))
+		if (xmlStrEqual (child->name, "sequence"))
 		{
 			s = xmlNodeGetContent (child);
 
 			sequences = g_slist_prepend (sequences, s);
 		}
-		else if (xmlStrEqual (child->name, (const xmlChar*) "action"))
+		else if (xmlStrEqual (child->name, "action"))
 		{
 			if (action == NULL)
 			{
@@ -145,7 +145,7 @@ load_one_gesture (EphyGesturesExtension *extension,
 	{
 		g_hash_table_insert (extension->priv->gestures,
 				     g_strdup (l->data),
-				     g_strdup ((char*)action));
+				     g_strdup (action));
 		xmlFree (l->data);
 	}
 
@@ -175,7 +175,7 @@ load_gestures (EphyGesturesExtension *extension,
 	}
 
 	root = xmlDocGetRootElement (doc);
-	if (root == NULL || strcmp ((char*)root->name, EPHY_GESTURES_XML_ROOT) != 0)
+	if (root == NULL || strcmp (root->name, EPHY_GESTURES_XML_ROOT) != 0)
 	{
 		g_warning ("Gestures definitions file %s has wrong format '%s'"
 		           "(expected " EPHY_GESTURES_XML_ROOT ")\n",
@@ -183,8 +183,8 @@ load_gestures (EphyGesturesExtension *extension,
 		goto out;
 	}
 
-	tmp = xmlGetProp (root, (const xmlChar*) "version");
-	if (tmp  == NULL || strcmp ((char*) tmp, (char*) EPHY_GESTURES_XML_VERSION) != 0)
+	tmp = xmlGetProp (root, "version");
+	if (tmp  == NULL || strcmp (tmp, EPHY_GESTURES_XML_VERSION) != 0)
 	{
 		g_warning ("Gestures definitions file %s has wrong format version %s"
 			   "(expected " EPHY_GESTURES_XML_VERSION ")\n",
@@ -194,7 +194,7 @@ load_gestures (EphyGesturesExtension *extension,
 
 	for (child = root->children; child != NULL; child = child->next)
 	{
-		if (xmlStrEqual (child->name, (const xmlChar*) "gesture"))
+		if (xmlStrEqual (child->name, "gesture"))
 		{
 			load_one_gesture (extension, child);
 		}
@@ -286,7 +286,7 @@ gesture_performed_cb (EphyGesture *gesture,
 		GtkUIManager *manager;
 		GtkAction *action;
 		
-		manager = GTK_UI_MANAGER (window->ui_merge);
+		manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 		
 		action = gtk_ui_manager_get_action (manager, path);
 		
@@ -340,12 +340,14 @@ dom_mouse_down_cb (EphyEmbed *embed,
 }
 
 static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphyGesturesExtension *extension)
+impl_attach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
 	EphyEmbed *embed;
 
+	LOG ("Attach tab")
+
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	embed = ephy_tab_get_embed (tab);
@@ -356,12 +358,14 @@ tab_added_cb (GtkWidget *notebook,
 }
 
 static void
-tab_removed_cb (GtkWidget *notebook,
-		EphyTab *tab,
-		EphyGesturesExtension *extension)
+impl_detach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
 	EphyEmbed *embed;
 
+	LOG ("Detach tab")
+
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	embed = ephy_tab_get_embed (tab);
@@ -371,61 +375,11 @@ tab_removed_cb (GtkWidget *notebook,
 		(embed, G_CALLBACK (dom_mouse_down_cb), extension);
 }
 
-static void
-impl_attach_window (EphyExtension *extension,
-		    EphyWindow *window)
-{
-	GtkWidget *notebook;
-	GList *tabs, *l;
-
-	tabs = ephy_window_get_tabs (window);
-
-	for (l = tabs; l != NULL; l = g_list_next (l))
-	{
-		tab_added_cb (NULL, l->data,
-			      (EphyGesturesExtension *) extension);
-	}
-
-	g_list_free (tabs);
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_connect (notebook, "tab_added",
-			  G_CALLBACK (tab_added_cb), extension);
-	g_signal_connect (notebook, "tab_removed",
-			  G_CALLBACK (tab_removed_cb), extension);
-}
-
-static void
-impl_detach_window (EphyExtension *extension,
-		    EphyWindow *window)
-{
-	GtkWidget *notebook;
-	GList *tabs, *l;
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_added_cb), extension);
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_removed_cb), extension);
-
-	tabs = ephy_window_get_tabs (window);
-
-	for (l = tabs; l != NULL; l = g_list_next (l))
-	{
-		tab_removed_cb (NULL, l->data,
-				(EphyGesturesExtension *) extension);
-	}
-
-	g_list_free (tabs);
-}
-
 static void
 ephy_gestures_extension_iface_init (EphyExtensionIface *iface)
 {
-	iface->attach_window = impl_attach_window;
-	iface->detach_window = impl_detach_window;
+	iface->attach_tab = impl_attach_tab;
+	iface->detach_tab = impl_detach_tab;
 }
 
 static void
